==> datasets-1.6.2.tar.gz: datasets-1.6.2/datasets/ncslgr/README.md <==
---
annotations_creators:
- expert-generated
language_creators:
- expert-generated
languages:
- ase
- en
licenses:
- mit
multilinguality:
- translation
size_categories:
- n<1K
source_datasets:
- original
task_categories:
- conditional-text-generation
task_ids:
- machine-translation
---

# Dataset Card for NCSLGR

## Table of Contents
- [Dataset Description](#dataset-description)
  - [Dataset Summary](#dataset-summary)
  - [Supported Tasks](#supported-tasks-and-leaderboards)
  - [Languages](#languages)
- [Dataset Structure](#dataset-structure)
  - [Data Instances](#data-instances)
  - [Data Fields](#data-instances)
  - [Data Splits](#data-instances)
- [Dataset Creation](#dataset-creation)
  - [Curation Rationale](#curation-rationale)
  - [Source Data](#source-data)
  - [Annotations](#annotations)
  - [Personal and Sensitive Information](#personal-and-sensitive-information)
- [Considerations for Using the Data](#considerations-for-using-the-data)
  - [Social Impact of Dataset](#social-impact-of-dataset)
  - [Discussion of Biases](#discussion-of-biases)
  - [Other Known Limitations](#other-known-limitations)
- [Additional Information](#additional-information)
  - [Dataset Curators](#dataset-curators)
  - [Licensing Information](#licensing-information)
  - [Citation Information](#citation-information)
  - [Contributions](#contributions)

## Dataset Description

- **Homepage:** https://www.bu.edu/asllrp/ncslgr.html
- **Repository:**
- **Paper:** 
- **Leaderboard:**
- **Point of Contact:** 

### Dataset Summary

A small corpus of American Sign Language (ASL) video data from native signers, annotated with non-manual features.

### Supported Tasks and Leaderboards

[More Information Needed]

### Languages

- American Sign Language
- English

## Dataset Structure

### Data Instances

[More Information Needed]

### Data Fields

- eaf: path to an ELAN annotation file
- videos: sequence of strings to video paths
- sentences: sequence of parallel sentences 
    - gloss: American Sign Language gloss annotations
    - text: English text

### Data Splits

None

## Dataset Creation

### Curation Rationale

[More Information Needed]

### Source Data

#### Initial Data Collection and Normalization

[More Information Needed]

#### Who are the source language producers?

[More Information Needed]

### Annotations

#### Annotation process

[More Information Needed]

#### Who are the annotators?

[More Information Needed]

### Personal and Sensitive Information

[More Information Needed]

## Considerations for Using the Data

### Social Impact of Dataset

[More Information Needed]

### Discussion of Biases

[More Information Needed]

### Other Known Limitations

[More Information Needed]

## Additional Information

### Dataset Curators

[More Information Needed]

### Licensing Information

[More Information Needed]

### Citation Information

```bibtex
@misc{dataset:databases2007volumes,
    title={Volumes 2--7},
    author={Databases, NCSLGR},
    year={2007},
    publisher={American Sign Language Linguistic Research Project (Distributed on CD-ROM~…}
}
```

### Contributions

Thanks to [@AmitMY](https://github.com/AmitMY) for adding this dataset.

==> datasets-1.18.1.tar.gz: datasets-1.18.1/datasets/ncslgr/README.md <==
---
annotations_creators:
- expert-generated
language_creators:
- expert-generated
languages:
- ase
- en
licenses:
- mit
multilinguality:
- translation
size_categories:
- n<1K
source_datasets:
- original
task_categories:
- conditional-text-generation
task_ids:
- machine-translation
paperswithcode_id: null
pretty_name: NCSLGR
---

# Dataset Card for NCSLGR

## Table of Contents
- [Dataset Description](#dataset-description)
  - [Dataset Summary](#dataset-summary)
  - [Supported Tasks and Leaderboards](#supported-tasks-and-leaderboards)
  - [Languages](#languages)
- [Dataset Structure](#dataset-structure)
  - [Data Instances](#data-instances)
  - [Data Fields](#data-fields)
  - [Data Splits](#data-splits)
- [Dataset Creation](#dataset-creation)
  - [Curation Rationale](#curation-rationale)
  - [Source Data](#source-data)
  - [Annotations](#annotations)
  - [Personal and Sensitive Information](#personal-and-sensitive-information)
- [Considerations for Using the Data](#considerations-for-using-the-data)
  - [Social Impact of Dataset](#social-impact-of-dataset)
  - [Discussion of Biases](#discussion-of-biases)
  - [Other Known Limitations](#other-known-limitations)
- [Additional Information](#additional-information)
  - [Dataset Curators](#dataset-curators)
  - [Licensing Information](#licensing-information)
  - [Citation Information](#citation-information)
  - [Contributions](#contributions)

## Dataset Description

- **Homepage:** https://www.bu.edu/asllrp/ncslgr.html
- **Repository:**
- **Paper:** 
- **Leaderboard:**
- **Point of Contact:** 

### Dataset Summary

A small corpus of American Sign Language (ASL) video data from native signers, annotated with non-manual features.

### Supported Tasks and Leaderboards

[More Information Needed]

### Languages

- American Sign Language
- English

## Dataset Structure

### Data Instances

[More Information Needed]

### Data Fields

- eaf: path to an ELAN annotation file
- videos: sequence of strings to video paths
- sentences: sequence of parallel sentences 
    - gloss: American Sign Language gloss annotations
    - text: English text

### Data Splits

None

## Dataset Creation

### Curation Rationale

[More Information Needed]

### Source Data

#### Initial Data Collection and Normalization

[More Information Needed]

#### Who are the source language producers?

[More Information Needed]

### Annotations

#### Annotation process

[More Information Needed]

#### Who are the annotators?

[More Information Needed]

### Personal and Sensitive Information

[More Information Needed]

## Considerations for Using the Data

### Social Impact of Dataset

[More Information Needed]

### Discussion of Biases

[More Information Needed]

### Other Known Limitations

[More Information Needed]

## Additional Information

### Dataset Curators

[More Information Needed]

### Licensing Information

[More Information Needed]

### Citation Information

```bibtex
@misc{dataset:databases2007volumes,
    title={Volumes 2--7},
    author={Databases, NCSLGR},
    year={2007},
    publisher={American Sign Language Linguistic Research Project (Distributed on CD-ROM~…}
}
```

### Contributions

Thanks to [@AmitMY](https://github.com/AmitMY) for adding this dataset.
